* Reproduction of Figure 1 of the paper
* "Export Diversification and Income Differences Reconsidered: The Extensive Product Margin in Theory and Application,"
* Review of World Economics, 152(2): 351-381; 2016, Karsten Mau

use "D:\Dokumente\Data\CCSK_replication_RES\data\diversification.dta", clear


* Select variables
rename reporter ISO3 	// Country identifier
rename T T_HS6			// Theil-Index
rename Soil s_oil		// Oil share in Exports
rename GDPpcppp gdppc	// GDP per capita
keep ISO3 year T_HS6 gdppc s_oil pop

* Harmonize country names
kountry ISO3, from(iso3c) marker
tab ISO3 if M==0
drop M
rename NAME country
order year ISO3 country 
sort year ISO3 country 

* Tag countries with average population below 1 m and oil exports above 50 percent
bys country: egen mpop=mean(pop)
bys country: egen moil=mean(s_oil)
gen flag=1 if mpop<1000000 | moil>=.5
drop m* 

* Rescale gdppc, collapse over countries, and compute square of log-gdppc
sort year ISO3 country 
replace gdppc=gdppc/1000
collapse (mean) T_HS6 gdppc, by(ISO3 flag)
replace gdppc=ln(gdppc)
gen gdppc2=gdppc^2

* Estimate and predict: linear regression (OLS)...
reg T_HS6 gdppc gdppc2 if flag!=1, vce(cluster ISO3)
predict T_HS6_hat
* ... and Lowess
lowess T_HS6 gdppc if flag!=1, gen(T_HS6_lo) nodraw

* "un-log" gdppc variable for graphical representation
sort gdppc
replace gdppc=exp(gdppc)

* Make figure for countries w/ avg. GDPpc<=60,000: scatterplot (real data), line1 (linear prediction), line2 (lowess prediction), log-scale
twoway 	scatter T_HS6 gdppc if flag!=1&gdppc<=60, msy(O)   || scatter T_HS6 gdppc if flag==1&gdppc<=60, msy(Oh) || ///
		line T_HS6_hat gdppc if gdppc<=60, clpattern(dash) lcolor(black) || line T_HS6_lo gdppc if gdppc<=60, lcolor(red) graphregion(color(white)) ///
		ytitle("Theil Index") xtitle(" " "GDP per capita; 1,000 international dollars (PPP 2005)") ylab(, angle(h)) xsc(log)  ///
		xlab(.5 2 8 32) ylab(1 3 5 7) ///
		title("") legend(off) text(2 3 "China") text(3 2 "India") text(7 10 "Botswana") text(4.3 34 "Norway")
