* Reproduction of Figure 4 of the paper
* "Export Diversification and Income Differences Reconsidered: The Extensive Product Margin in Theory and Application,"
* Review of World Economics, 152(2): 351-381; 2016, Karsten Mau

cd "D:\Dokumente\Papiere\Export Diversification\"
use data\dataset_balanced, clear

* select sample from CEPII BACI
keep if baci==1
gen flag=1 if moil>=.5|mpop<1			// tag oil and small countries
keep ISO country t *baci96 gdppc flag	// Select variables
keep ISO country t N* gdppc flag
compress

* collapse over countries and rescale diversification measures as fraction of available goods
collapse N_pos_baci96 N_tot_baci96 N_50k_baci96 N_10p_baci96 gdppc_wdi, by(ISO country flag)
gen DA=N_tot_baci96/N_pos_baci96	// Figure 4a
gen DB=N_50k_baci96/N_pos_baci96	// Figure 4b
gen DC=N_10p_baci96/N_pos_baci96	// Figure 4c
drop N*


* rename and rescale GDPpc
rename gdppc_ gdppc
replace gdppc=gdppc/1000

*** Make Figure 4(a)
replace gdppc=ln(gdppc) 						// take logs
gen gdppc2=gdppc^2
reg DA gdppc gdppc2 if flag!=1					// linear prediction
predict DA_hat if flag!=1
lowess DA gdppc if flag!=1, gen(DA_lo) nodraw	// lowess prediction
replace gdppc=exp(gdppc)						// un-log GDPpc
sort gdppc
twoway 	scatter DA gdppc if flag!=1&gdppc<=60, msy(O)  || ///
		line DA_hat gdppc if gdppc<=60, clpattern(dash) lcolor(black) || line DA_lo gdppc if gdppc<=60, lcolor(red) graphregion(color(white)) ///
		ytitle("Fraction Exported: D(HS6)") xtitle(" " "GDP per capita; 1,000 international dollars (PPP 2005)") ylab(, angle(h)) xsc(log)  ///
		xlab(.5 2 8 32) ylab(0(0.2)1) title("") legend(off) text(.975 2.5 "China") text(.95 .5 "India") ///
		text(.225 4.5 "Jamaica") text(.55 15 "Cyprus") text(.4 10 "Uruguay") text(.85 1 "Indonesia")

*** Make Figure 4(b)
replace gdppc=ln(gdppc) 						// take logs
reg DB gdppc gdppc2 if flag!=1					// linear prediction
predict DB_hat if flag!=1
lowess DB gdppc if flag!=1, gen(DB_lo) nodraw	// lowess prediction
replace gdppc=exp(gdppc)						// un-log GDPpc
sort gdppc
twoway 	scatter DB gdppc if flag!=1&gdppc<=60, msy(O) || ///
		line DB_hat gdppc if gdppc<=60, clpattern(dash) lcolor(black) || line DB_lo gdppc if gdppc<=60, lcolor(red) graphregion(color(white)) ///
		ytitle("Fraction Exported: D(EV02)") xtitle(" " "GDP per capita; 1,000 international dollars (PPP 2005)") ylab(, angle(h)) xsc(log)  ///
		xlab(.5 2 8 32) ylab(0(0.2)1) ///
		title("") legend(off) 

*** Make Figure 4(c)
replace gdppc=ln(gdppc) 						// take logs
reg DC gdppc gdppc2 if flag!=1					// linear prediction
predict DC_hat if flag!=1
lowess DC gdppc if flag!=1, gen(DC_lo) nodraw	// lowess prediction
replace gdppc=exp(gdppc)						// un-log GDPpc
sort gdppc
twoway 	scatter DC gdppc if flag!=1&gdppc<=60, msy(O) || ///
		line DC_hat gdppc if gdppc<=60, clpattern(dash) lcolor(black) || line DC_lo gdppc if gdppc<=60, lcolor(red) graphregion(color(white)) ///
		ytitle("Fraction Exported: D(KR13)") xtitle(" " "GDP per capita; 1,000 international dollars (PPP 2005)") ylab(, angle(h)) xsc(log)  ///
		xlab(.5 2 8 32) ylab(0(0.06)0.3) title("") legend(off) 

