* Reproduction of Table 2 and Figure 5 of the paper
* "Export Diversification and Income Differences Reconsidered: The Extensive Product Margin in Theory and Application,"
* Review of World Economics, 152(2): 351-381; 2016, Karsten Mau

clear all
cd "C:\Users\Karsten Mau\Documents\Papiere\Export Diversification\"

**************************************************
**** Table 2, Panel A: CEPII BACI96 data
**************************************************
**********************
****    1 Setup   **** 
use data\dataset_balanced, clear
keep if baci==1
drop if moil>=.5|mpop<1
keep ISO country t *baci96 pop gdppc distR
keep ISO country t N* pop gdppc distR
compress
* Set balanced panel
drop if gdppc==.
bys country: gen obs=_N
sum obs
drop if obs<r(max)
drop obs
egen id=group(country)
xtset id t
* Compute fraction of goods exported
replace N_tot=N_tot/N_pos
replace N_50k=N_50k/N_pos
replace N_10p=N_10p/N_pos
* Construct subperiods according to periods of HS Revisions and compute period averages of all variables
gen p=0 if t>=1998
replace p=1 if t>=2002
replace p=2 if t>=2007
la def p 0 "1998-2001" 1 "2002-2006" 2 "2007-2009"
la val p p
collapse N* pop_wdi gdppc_wdi distR_cepii, by(ISO country p id)
* Relative Diversification
local vars "N_tot N_50k N_10p pop_wdi gdppc_wdi distR_cepii"
foreach v of local vars{
bys p: egen m`v'=mean(`v')
gen r`v'=`v'/m`v'
drop m`v'
}
gen limit=N_tot
gen tag=1 if limit>0.8
sort country tag
bys country: replace tag=tag[1]
local vars "N_tot pop_wdi gdppc_wdi distR_cepii"
foreach v of local vars{
bys p: egen m`v'=mean(`v') if tag!=1
gen r2`v'=`v'/m`v' if tag!=1
drop m`v'
}
* Take logs of the RHS variables
gen lny=ln(rgdppc)
gen lny2=lny^2
gen lnL=ln(rpop)
gen lndR=ln(rdistR)
gen r2lny=ln(r2gdppc)
gen r2lny2=r2lny^2
gen r2lnL=ln(r2pop)
gen r2lndR=ln(r2distR)
* Rename and label dependent variables
gen DA=rN_tot
gen r2DA=r2N_tot
gen DB=rN_50k
gen DC=rN_10p
la var ISO "Country ISO3 Code"
la var country "Country"
la var p "Period"
la var lny "(log) GDPpc"
la var lny2 "(log) GDPpc2"
la var lnL "(log) Population"
la var lndR "(log) Distance from Remote Destinations"
la var r2lny "(log) GDPpc"
la var r2lny2 "(log) GDPpc2"
la var r2lnL "(log) Population"
la var r2lndR "(log) Distance from Remote Destinations"
la var DA "Count: All Goods Exported"
la var r2DA "Count: All Goods Exported"
la var DB "Count: Threshold $50,000"
la var DC "Count: Threshold p[10]"
* Drop variables not needed for the analysis and reset panel 
drop *N* *pop_wdi *gdppc_wdi *distR_cepii
xtset id p

**********************
**** 2 Estimation ****
* Total Count Measure DA: 
* Censored sample, across periods and with and without squared log-gdppc (Main text)
qui xtreg r2DA r2lny r2lny2 r2lnL r2lndR, be
eststo DAbacicens
qui xtreg r2DA r2lny r2lnL r2lndR, be
eststo DAbacilincens
* Absolute Threshold at 50k dollar value, DB:
* Full sample, across periods and with and without squared log-gdppc (Main text)
qui xtreg DB lny lny2 lnL lndR, be
eststo DBbacifull
qui xtreg DB lny lnL lndR, be
eststo DBbacilinfull
* Relative Treshold at 10th percentile, DC: 
* Full sample, across periods and with and without squared log-gdppc (Main text)
qui xtreg DC lny lny2 lnL lndR, be
eststo DCbacifull
qui xtreg DC lny lnL lndR, be
eststo DCbacilinfull


**************************************************
**** Figures 5a-c 
**************************************************
preserve
xtreg r2DA r2lny r2lnL r2lndR, be
predict res, ue
egen mL=mean(r2lnL)
egen mR=mean(r2lndR)
replace r2lnL=mL
replace r2lndR=mR
predict DAhat
replace DAhat=DAhat+res
drop if r2DA==.
collapse r2DA DAhat r2lny, by(ISO)
twoway 	qfitci DAhat r2lny, msy(Oh) mcolor(red) || scatter DAhat r2lny, mcolor(navy) ///
		graphregion(color(white)) legend(off)  ///
		text(0.85 5.65 "Censoring Threshold") ylab(,angle(h)) ytitle("") xtitle("") ///
		name(fig5a, replace)
restore
preserve
xtreg DB lny lnL lndR i.p, be
predict res, ue
bys p: egen mL=mean(lnL)
bys p: egen mR=mean(lndR)
replace lnL=mL
replace lndR=mR
predict DBhat
replace DBhat=DBhat+res
collapse DB DBhat lny, by(ISO)
twoway 	qfitci DBhat lny, msy(Oh) mcolor(red) || scatter DBhat lny, mcolor(navy) ///
		graphregion(color(white)) legend(off)  ///
		ylab(,angle(h)) ytitle("") xtitle("") ///
		name(fig5b, replace)
restore
preserve
xtreg DC lny lnL lndR i.p, be
predict res, ue
bys p: egen mL=mean(lnL)
bys p: egen mR=mean(lndR)
replace lnL=mL
replace lndR=mR
predict DChat
replace DChat=DChat+res
collapse DC DChat lny, by(ISO)
twoway 	qfitci DChat lny, msy(Oh) mcolor(red) || scatter DChat lny, mcolor(navy)  ///
		graphregion(color(white)) legend(off) ///
		ylab(,angle(h)) ytitle("") xtitle("") ///
		name(fig5c, replace)
restore 


**************************************************
***** Table 2, Panel B: UN Comtrade data
**************************************************
* 1 Setup
use data\dataset_balanced, clear
keep if comtrade==1
drop if moil>=.5|mpop<1
keep ISO country t *comtrade pop gdppc distR
keep ISO country t N* pop gdppc distR
compress
* Allow unbalanced panel
drop if gdppc==.
egen id=group(country)
xtset id t
* Compute fraction of goods exported
gen N_pos=4252
replace N_tot=N_tot/N_pos
replace N_50k=N_50k/N_pos
replace N_10p=N_10p/N_pos
drop N_pos
* Construct subperiods according to periods of HS Revisions and compute period averages of all variables
gen p=0 if t>=1988
replace p=1 if t>=1996
replace p=2 if t>=2002
replace p=3 if t>=2007
replace p=4 if t>=2012
la def p 0 "1988-1995" 1 "1996-2001" 2 "2002-2006" 3 "2007-2011" 4 "2012-2013"
la val p p
collapse N* pop_wdi gdppc_wdi distR_cepii, by(ISO country p id)
* Relative Diversification
local vars "N_tot N_50k N_10p pop_wdi gdppc_wdi distR_cepii"
foreach v of local vars{
bys p: egen m`v'=mean(`v')
gen r`v'=`v'/m`v'
drop m`v'
}
gen limit=N_tot
gen tag=1 if limit>0.8
sort country tag
bys country: replace tag=tag[1]
local vars "N_tot pop_wdi gdppc_wdi distR_cepii"
foreach v of local vars{
bys p: egen m`v'=mean(`v') if tag!=1
gen r2`v'=`v'/m`v' if tag!=1
drop m`v'
}
* Take logs of the RHS variables
gen lny=ln(rgdppc)
gen lny2=lny^2
gen lnL=ln(rpop)
gen lndR=ln(rdistR)
gen r2lny=ln(r2gdppc)
gen r2lny2=r2lny^2
gen r2lnL=ln(r2pop)
gen r2lndR=ln(r2distR)
* Rename and label dependent variables
gen DA=rN_tot
gen r2DA=r2N_tot
gen DB=rN_50k
gen DC=rN_10p
la var ISO "Country ISO3 Code"
la var country "Country"
la var p "Period"
la var lny "(log) GDPpc"
la var lny2 "(log) GDPpc2"
la var lnL "(log) Population"
la var lndR "(log) Distance from Remote Destinations"
la var r2lny "(log) GDPpc"
la var r2lny2 "(log) GDPpc2"
la var r2lnL "(log) Population"
la var r2lndR "(log) Distance from Remote Destinations"
la var DA "Count: All Goods Exported"
la var r2DA "Count: All Goods Exported"
la var DB "Count: Threshold $50,000"
la var DC "Count: Threshold p[10]"
* Drop variables not needed for the analysis and reset panel 
drop *N* *pop_wdi *gdppc_wdi *distR_cepii
xtset id p


**** 2 Estimation ***
* Full and censored sample, across periods and with and without squared log-gdppc (Main text)
qui xtreg r2DA r2lny r2lny2 r2lnL r2lndR, be
eststo DAcomtradecens
qui xtreg r2DA r2lny r2lnL r2lndR, be
eststo DAcomtradelincens
* Absolute Treshold at 50,000 USD, DB: 
* Full sample, across periods and with and without squared log-gdppc (Main text)
qui xtreg DB lny lny2 lnL lndR, be
eststo DBcomtradefull
qui xtreg DB lny lnL lndR, be
eststo DBcomtradelinfull
* Relative Treshold at 10th percentile, DC: 
* Full sample, by period and with and without squared log-gdppc (Appendix)
* Full sample, across periods and with and without squared log-gdppc (Main text)
qui xtreg DC lny lny2 lnL lndR, be
eststo DCcomtradefull
qui xtreg DC lny lnL lndR, be
eststo DCcomtradelinfull


**************************************************
***** Table 2, Panel C: US Import data
**************************************************

**** 1 Setup ***
use data\dataset_balanced, clear
keep if schott==1
drop if moil>=.5|mpop<1
keep ISO country t *schott pop gdppc distUS
keep ISO country t N* pop gdppc distUS
compress
* Set balanced panel
drop if gdppc==.
bys country: gen obs=_N
sum obs
drop if obs<r(max)
drop obs
egen id=group(country)
xtset id t
codebook country
* Compute fraction of goods exported
replace N_tot=N_tot/N_pos
replace N_10k=N_10k/N_pos
replace N_10p=N_10p/N_pos
drop N_pos
* Construct subperiods according to periods of HS Revisions and compute period averages of all variables
gen p=0 if t>=1992
replace p=1 if t>=1996
replace p=2 if t>=2002
replace p=3 if t>=2007
la def p 0 "1992-1995" 1 "1996-2001" 2 "2002-2006" 3 "2007-2009"
la val p p
collapse N* pop_wdi gdppc_wdi distUS, by(ISO country p id)
* Relative Diversification
local vars "N_tot N_10k N_10p pop_wdi gdppc_wdi distUS"
foreach v of local vars{
bys p: egen m`v'=mean(`v')
replace `v'=`v'/m`v'
drop m`v'
}
* Take logs of the RHS variables
gen lny=ln(gdppc)
gen lny2=lny^2
gen lnL=ln(pop)
gen lnd=ln(distUS)
* Rename and label dependent variables (logs!)
gen DA=ln(N_tot)
gen DB=ln(N_10k)
gen DC=ln(N_10p)
la var ISO "Country ISO3 Code"
la var country "Country"
la var p "Period"
la var lny "(log) GDPpc"
la var lny2 "(log) GDPpc2"
la var lnL "(log) Population"
la var lnd "(log) Distance from US"
la var DA "Count: All Goods Exported"
la var DB "(log) Count: Threshold $10,000"
la var DC "(log) Count: Threshold p[10]"
* Drop variables not needed for the analysis and reset panel
drop N* pop_wdi gdppc_wdi distUS
xtset id p

**** 2 Estimation ****
* Total Count Measure lnDA: 
* Full sample, across periods and with and without squared log-gdppc (Main text)
qui xtreg DA lny lnL lnd, be
eststo DAschottlin
qui xtreg DA lny lny2 lnL lnd, be
eststo DAschottfull
* Absolute Treshold at 10,000 USD, lnDB: 
* Full sample, across periods and with and without squared log-gdppc (Main text)
qui xtreg DB lny lnL lnd, be
eststo DBschottlin
qui xtreg DB lny lny2 lnL lnd, be
eststo DBschottfull
* Full sample, across periods and with and without squared log-gdppc (Main text)
qui xtreg DC lny lnL lnd, be
eststo DCschottlin
qui xtreg DC lny lny2 lnL lnd, be
eststo DCschottfull


**************************************************
***** ***** Main Text Tables ***** *****
**************************************************

***** TABLE 2: Average Fraction of Products Exported; BE-Estimator, Alternative Count Thresholds

* Panel A: Alternative Count Measures: CEPII BACI 1998-2009
esttab 	DAbacilincens DAbacicens DBbacilinfull DBbacifull DCbacilinfull DCbacifull, ///
		drop(_cons) sfmt(%5.3fc) se(%5.3f) star(a 0.1 * 0.05 ** 0.01) stats(N N_g r2) mtitle label

* Panel B: Alternative Count Measures: UN COMTRADE 1988-2013
esttab 	DAcomtradelincens DAcomtradecens DBcomtradelinfull DBcomtradefull DCcomtradelinfull DCcomtradefull, ///
		drop(_cons) sfmt(%5.3fc) se(%5.3f) star(a 0.1 * 0.05 ** 0.01) stats(N N_g r2) mtitle label
		
* Panel C: Alternative Count Measures: Schott (2008) 1992-2009
esttab 	DAschottlin DAschottfull DBschottlin DBschottfull DCschottlin DCschottfull, ///
		drop(_cons) sfmt(%5.3fc) se(%5.3f) star(a 0.1 * 0.05 ** 0.01) stats(N N_g r2) mtitle label


		
