* Reproduction of Table 3 of the paper
* "Export Diversification and Income Differences Reconsidered: The Extensive Product Margin in Theory and Application,"
* Review of World Economics, 152(2): 351-381; 2016, Karsten Mau

clear all
cd "C:\Users\Karsten Mau\Documents\Papiere\Export Diversification\"

*CEPII BACI96 DATA
* Setup
use data\dataset_balanced, clear
keep if baci==1
drop if moil>=.5|mpop<1
keep ISO country t *baci96 pop gdppc distR
keep ISO country t N* pop gdppc distR
compress
* Set balanced panel
drop if gdppc==.
bys country: gen obs=_N
sum obs
drop if obs<r(max)
drop obs
egen id=group(country)
xtset id t
* Compute fraction of goods exported
replace N_tot=N_tot/N_pos
replace N_50k=N_50k/N_pos
replace N_10p=N_10p/N_pos
* Relative Diversification
local vars "N_50k N_10p pop_wdi gdppc_wdi distR_cepii"
foreach v of local vars{
bys t: egen m`v'=mean(`v')
gen r`v'=`v'/m`v'
drop m`v'
}
gen limit=N_tot
gen tag=1 if limit>0.8
sort country tag
bys country: replace tag=tag[1]
local vars "N_tot pop_wdi gdppc_wdi distR_cepii"
foreach v of local vars{
bys t: egen m`v'=mean(`v') if tag!=1
gen r2`v'=`v'/m`v' if tag!=1
drop m`v'
}
* Take logs of the RHS variables
gen lny=ln(rgdppc)
gen lny2=lny^2
gen lnL=ln(rpop)
gen lndR=ln(rdistR)
gen r2lny=ln(r2gdppc)
gen r2lny2=r2lny^2
gen r2lnL=ln(r2pop)
gen r2lndR=ln(r2distR)
* Rename and label dependent variables
gen DA=r2N_tot
gen DB=rN_50k
gen DC=rN_10p
la var ISO "Country ISO3 Code"
la var country "Country"
la var p "Period"
la var lny "(log) GDPpc"
la var lny2 "(log) GDPpc2"
la var lnL "(log) Population"
la var lndR "(log) Distance from Remote Destinations"
la var r2lny "(log) GDPpc"
la var r2lny2 "(log) GDPpc2"
la var r2lnL "(log) Population"
la var r2lndR "(log) Distance from Remote Destinations"
la var DA "Count: All Goods Exported"
la var DB "Count: Threshold $50,000"
la var DC "Count: Threshold p[10]"
* Drop variables not needed for the analysis and reset panel 
drop *N* *pop_wdi *gdppc_wdi *distR_cepii
xtset id t

* Tests
local vars "r2lny r2lnL r2lndR"
foreach v of local vars {
bys id: egen be`v'=mean(`v')
bys id: gen fe`v'=`v'-be`v'
}
xtreg DA fe* be*, re robust
test fer2lny=ber2lny
gen Dp0=r(p)
gen Dchi20=r(chi2)
gen Dfe0=_b[fer2lny]
gen Dfese0=_se[fer2lny]
gen Dbe0=_b[ber2lny]
gen Dbese0=_se[ber2lny]
gen theta0=_b[fer2lnL]/_b[fer2lny]
drop fe* be* 
local vars "lny lnL lndR"
foreach v of local vars {
bys id: egen be`v'=mean(`v')
bys id: gen fe`v'=`v'-be`v'
}
xtreg DB fe* be*, re robust
test felny=belny
gen Dp1=r(p)
gen Dchi21=r(chi2)
gen Dfe1=_b[felny]
gen Dfese1=_se[felny]
gen Dbe1=_b[belny]
gen Dbese1=_se[belny]
gen theta1=_b[felnL]/_b[felny]
xtreg DC fe* be*, re robust
test felny=belny
gen Dp2=r(p)
gen Dchi22=r(chi2)
gen Dfe2=_b[felny]
gen Dfese2=_se[felny]
gen Dbe2=_b[belny]
gen Dbese2=_se[belny]
gen theta2=_b[felnL]/_b[felny]

* test squared relationship
xtreg DA r2lny r2lny2 r2lnL r2lndR, fe robust
eststo DAbaci
xtreg DB lny lny2 lnL lndR, fe robust
eststo DBbaci
xtreg DC lny lny2 lnL lndR, fe robust
eststo DCbaci
keep D* theta*
drop DA DB DC
collapse *
gen data="CEPII BACI96"
reshape long Dp Dchi2 Dfe Dfese Dbe Dbese theta, i(data) j(ind)
la def ind 0 "Total Count" 1 "Abs. Thresh." 2 "Rel. Thresh."
la val ind ind
save estimation\baci96, replace





*COMTRADE DATA
* Setup
use data\dataset_balanced, clear
keep if comtrade==1
drop if moil>=.5|mpop<1
keep ISO country t *comtrade pop gdppc distR
keep ISO country t N* pop gdppc distR
compress

* Set balanced panel
drop if gdppc==.
egen id=group(country)
xtset id t

* Compute fraction of goods exported
gen N_pos=4252
replace N_tot=N_tot/N_pos
replace N_50k=N_50k/N_pos
replace N_10p=N_10p/N_pos

* Relative Diversification
local vars "N_50k N_10p pop_wdi gdppc_wdi distR_cepii"
foreach v of local vars{
bys t: egen m`v'=mean(`v')
gen r`v'=`v'/m`v'
drop m`v'
}

gen limit=N_tot
gen tag=1 if limit>0.8
sort country tag
bys country: replace tag=tag[1]

local vars "N_tot pop_wdi gdppc_wdi distR_cepii"
foreach v of local vars{
bys t: egen m`v'=mean(`v') if tag!=1
gen r2`v'=`v'/m`v' if tag!=1
drop m`v'
}

* Take logs of the RHS variables
gen lny=ln(rgdppc)
gen lny2=lny^2
gen lnL=ln(rpop)
gen lndR=ln(rdistR)

gen r2lny=ln(r2gdppc)
gen r2lny2=r2lny^2
gen r2lnL=ln(r2pop)
gen r2lndR=ln(r2distR)

* Rename and label dependent variables
gen DA=r2N_tot
gen DB=rN_50k
gen DC=rN_10p

la var ISO "Country ISO3 Code"
la var country "Country"
la var p "Period"
la var lny "(log) GDPpc"
la var lny2 "(log) GDPpc2"
la var lnL "(log) Population"
la var lndR "(log) Distance from Remote Destinations"
la var r2lny "(log) GDPpc"
la var r2lny2 "(log) GDPpc2"
la var r2lnL "(log) Population"
la var r2lndR "(log) Distance from Remote Destinations"
la var DA "Count: All Goods Exported"
la var DB "Count: Threshold $50,000"
la var DC "Count: Threshold p[10]"

* Drop variables not needed for the analysis and reset panel 
drop *N* *pop_wdi *gdppc_wdi *distR_cepii
xtset id t



* Tests

local vars "r2lny r2lnL r2lndR"
foreach v of local vars {
bys id: egen be`v'=mean(`v')
bys id: gen fe`v'=`v'-be`v'
}

xtreg DA fe* be*, re robust
test fer2lny=ber2lny
gen Dp0=r(p)
gen Dchi20=r(chi2)
gen Dfe0=_b[fer2lny]
gen Dfese0=_se[fer2lny]
gen Dbe0=_b[ber2lny]
gen Dbese0=_se[ber2lny]
gen theta0=_b[fer2lnL]/_b[fer2lny]

drop fe* be* 
local vars "lny lnL lndR"
foreach v of local vars {
bys id: egen be`v'=mean(`v')
bys id: gen fe`v'=`v'-be`v'
}

xtreg DB fe* be*, re robust
test felny=belny
gen Dp1=r(p)
gen Dchi21=r(chi2)
gen Dfe1=_b[felny]
gen Dfese1=_se[felny]
gen Dbe1=_b[belny]
gen Dbese1=_se[belny]
gen theta1=_b[felnL]/_b[felny]

xtreg DC fe* be*, re robust
test felny=belny
gen Dp2=r(p)
gen Dchi22=r(chi2)
gen Dfe2=_b[felny]
gen Dfese2=_se[felny]
gen Dbe2=_b[belny]
gen Dbese2=_se[belny]
gen theta2=_b[felnL]/_b[felny]

* test squared relationship
xtreg DA r2lny r2lny2 r2lnL r2lndR, fe robust
eststo DAcomtrade
xtreg DB lny lny2 lnL lndR, fe robust
eststo DBcomtrade
xtreg DC lny lny2 lnL lndR, fe robust
eststo DCcomtrade

keep D* theta*
drop DA DB DC
collapse *
gen data="UN COMTRADE"
reshape long Dp Dchi2 Dfe Dfese Dbe Dbese theta, i(data) j(ind)
la def ind 0 "Total Count" 1 "Abs. Thresh." 2 "Rel. Thresh."
la val ind ind
save estimation\comtrade, replace




*CCSK DATA
* Setup
use data\dataset_balanced, clear
keep if ccsk==1
drop if moil>=.5|mpop<1
keep ISO country t *ccsk pop gdppc distR
keep ISO country t N* pop gdppc distR
compress

* Set balanced panel
drop if gdppc==.
bys country: gen obs=_N
sum obs
drop if obs<r(max)
drop obs
egen id=group(country)
xtset id t

* Compute fraction of goods exported
replace N_tot=N_tot/N_pos

gen limit=N_tot
gen tag=1 if limit>0.8
sort country tag
bys country: replace tag=tag[1]
drop if tag==1

* Relative Diversification
local vars "N_tot pop_wdi gdppc_wdi distR_cepii"
foreach v of local vars{
bys t: egen m`v'=mean(`v')
gen r`v'=`v'/m`v'
drop m`v'
}

* Take logs of the RHS variables
gen lny=ln(rgdppc)
gen lny2=lny^2
gen lnL=ln(rpop)
gen lndR=ln(rdistR)
gen DA=N_tot

la var ISO "Country ISO3 Code"
la var country "Country"
la var p "Period"
la var lny "(log) GDPpc"
la var lny2 "(log) GDPpc2"
la var lnL "(log) Population"
la var lndR "(log) Distance from Remote Destinations"
la var DA "Count: All Goods Exported"

* Drop variables not needed for the analysis and reset panel 
drop N* pop_wdi gdppc_wdi distR_cepii
xtset id t



* Tests
local vars "lny lnL lndR"
foreach v of local vars {
bys id: egen be`v'=mean(`v')
bys id: gen fe`v'=`v'-be`v'
}

xtreg DA fe* be*, re robust
test felny=belny
gen Dp0=r(p)
gen Dchi20=r(chi2)
gen Dfe0=_b[felny]
gen Dfese0=_se[felny]
gen Dbe0=_b[belny]
gen Dbese0=_se[belny]
gen theta0=_b[felnL]/_b[felny]

* squared relationship
xtreg DA lny lny2 lnL lndR, fe robust
eststo DAccsk

keep D* theta
drop DA
collapse *
gen data="CCSK"
reshape long Dp Dchi2 Dfe Dfese Dbe Dbese theta, i(data) j(ind)
la def ind 0 "Total Count"
la val ind ind
save estimation\ccsk, replace






*US DATA
* Setup
use data\dataset_balanced, clear
keep if schott==1
drop if moil>=.5|mpop<1
keep ISO country t *schott pop gdppc distUS
keep ISO country t N* pop gdppc distUS
compress

* Set balanced panel
drop if gdppc==.
bys country: gen obs=_N
sum obs
drop if obs<r(max)
drop obs
egen id=group(country)
xtset id t

* Compute fraction of goods exported
replace N_tot=N_tot/N_pos
replace N_10k=N_10k/N_pos
replace N_10p=N_10p/N_pos

* Relative Diversification
local vars "N_tot N_10k N_10p pop_wdi gdppc_wdi distUS"
foreach v of local vars{
bys t: egen m`v'=mean(`v')
gen r`v'=`v'/m`v'
drop m`v'
}

* Take logs of the RHS variables
gen lny=ln(gdppc)
gen lny2=lny^2
gen lnL=ln(pop)
gen lnd=ln(distUS)

* Rename and label dependent variables
gen DA=ln(N_tot)
gen DB=ln(N_10k)
gen DC=ln(N_10p)

la var ISO "Country ISO3 Code"
la var country "Country"
la var p "Period"
la var lny "(log) GDPpc"
la var lny2 "(log) GDPpc2"
la var lnL "(log) Population"
la var lnd "(log) Distance from the US"
la var DA "Count: All Goods Exported"
la var DB "Count: Threshold $10,000"
la var DC "Count: Threshold p[10]"

* Drop variables not needed for the analysis and reset panel 
drop N* pop_wdi gdppc_wdi distUS
xtset id t


* Tests
local vars "lny lnL lnd"
foreach v of local vars {
bys id: egen be`v'=mean(`v')
bys id: gen fe`v'=`v'-be`v'
}

xtreg DA fe* be*, re robust
test felny=belny
gen Dp0=r(p)
gen Dchi20=r(chi2)
gen Dfe0=_b[felny]
gen Dfese0=_se[felny]
gen Dbe0=_b[belny]
gen Dbese0=_se[belny]
gen theta0=_b[felnL]/_b[felny]

xtreg DB fe* be*, re robust
test felny=belny
gen Dp1=r(p)
gen Dchi21=r(chi2)
gen Dfe1=_b[felny]
gen Dfese1=_se[felny]
gen Dbe1=_b[belny]
gen Dbese1=_se[belny]
gen theta1=_b[felnL]/_b[felny]

xtreg DC fe* be*, re robust
test felny=belny
gen Dp2=r(p)
gen Dchi22=r(chi2)
gen Dfe2=_b[felny]
gen Dfese2=_se[felny]
gen Dbe2=_b[belny]
gen Dbese2=_se[belny]
gen theta2=_b[felnL]/_b[felny]

* test squared relationship
xtreg DA lny lny2 lnL lnd, fe robust
eststo DAschott
xtreg DB lny lny2 lnL lnd, fe robust
eststo DBschott
xtreg DC lny lny2 lnL lnd, fe robust
eststo DCschott

keep D* theta*
drop DA DB DC
collapse *
gen data="Schott 2008"
reshape long Dp Dchi2 Dfe Dfese Dbe Dbese theta, i(data) j(ind)
la def ind 0 "Total Count" 1 "Abs. Thresh." 2 "Rel. Thresh."
la val ind ind





*** Merge files and make table:
append using estimation\baci96
append using estimation\comtrade
append using estimation\ccsk

sort ind data
format Dp %4.3f
format Dchi2 %4.2f
format Dfe %4.3f
format Dfese %4.3f
format Dbe %4.3f
format Dbese %4.3f
format theta %4.2f

* columns 1 - 6
order data ind Dfe* Dbe* Dchi2 Dp
* column 7
esttab DA* DB* DC*, keep(r2lny2 lny2) se mtitle


* Erase datasets from intermediate steps
erase estimation\baci96.dta
erase estimation\comtrade.dta
erase estimation\ccsk.dta
