* Reproduction of Table 4 Panel B of the paper
* "Export Diversification and Income Differences Reconsidered: The Extensive Product Margin in Theory and Application,"
* Review of World Economics, 152(2): 351-381; 2016, Karsten Mau

clear all
cd "C:\Users\Karsten Mau\Documents\Papiere\Export Diversification\"

use data\dataset_balanced, clear

sort country t
bys country: gen n=(pop-pop[_n-1])/(pop[_n-1])
gen ndg=n+0.05

keep if comtrade==1
drop if moil>=.5|mpop<1
keep ISO country t *comtrade pop gdppc gdp_wdi R distR dist_cepii open cap ndg
keep ISO country t N* pop gdppc gdp_wdi R distR dist_cepii open cap ndg
compress

drop if t<2000

* share of goods exported
replace N_tot=N_tot/4252
replace N_50k=N_50k/4252
replace N_10p=N_10p/4252
gen limit=N_tot
drop if N_tot>0.8

* balanced panel
drop if gdppc==.
drop if cap==.
bys country: gen obs=_N
sum obs
drop if obs<r(max)
drop obs
egen id=group(country)
xtset id t



* relative terms
gen s=cap/gdp_wdi
local vars "s ndg gdppc pop distR N_tot N_50k N_10p"
foreach v of local vars{
bys t: egen m`v'=mean(`v')
replace `v'=`v'/m`v'
drop m`v'
}

* log RHS variables
gen lnndg=ln(ndg)
gen lns=ln(s)
gen lny=ln(gdppc)
gen lny2=lny^2
gen lnL=ln(pop)
gen lnR=ln(R)
gen lndR=ln(distR)
gen lnd=ln(dist_cepii)
gen DA=ln(N_tot)
gen DB=ln(N_50k)
gen DC=ln(N_10p)

la var ISO "Country ISO3 Code"
la var country "Country"
la var lny "(log) GDPpc"
la var lny2 "(log) GDPpc2"
la var lnL "(log) Population"
la var lns "(log) investment rate"
la var lnndg "(log) growth of population/depreciation/technology"
la var lndR "(log) Distance from Remote Destinations"
la var lnd "(log) Distance from Destinations"
la var DA "(log) Count: Total"
la var DB "(log) Count: Threshold $50,000"
la var DC "(log) Count: Threshold p[10]"

drop N* pop_wdi gdppc_wdi dist_cepii distR_cepii R_cepii gdp_wdi cap ndg open
xtset id t

gen dDA=d.DA
bys country: egen mdDA=mean(dDA)
xtset id t
sum mdDA, d
gen tagDA=1 if mdDA>r(p75)
tab country if tagDA==1, sum(limit)

gen dDB=d.DB
bys country: egen mdDB=mean(dDB)
xtset id t
sum mdDB, d
gen tagDB=1 if mdDB>r(p75)
tab country if tagDB==1, sum(limit)

gen dDC=d.DC
bys country: egen mdDC=mean(dDC)
xtset id t
sum mdDC, d
gen tagDC=1 if mdDC>r(p75)
tab country if tagDC==1, sum(limit)

***** Dynamic Estimation, incl. lagged diversification; columns (3) and (4)
xtreg DA L.DA lny lnL lndR if tagDA==1, re
xtreg DA L.DA lny lnL lndR if tagDA==1, fe
xtabond2 DA L.DA lny lnL lndR if tagDA==1, gmm(L.DA, lag(1 1) collapse) gmm(L.lny, lag(1 2) collapse equ(level)) iv(lnL lndR) twostep robust small
eststo DAcol1

xtreg DA L.DA lny lny2 lnL lndR if tagDA==1, re
xtreg DA L.DA lny lny2 lnL lndR if tagDA==1, fe
xtabond2 DA L.DA lny lny2 lnL lndR if tagDA==1, gmm(L.DA, lag(1 1) collapse) gmm(L.lny, lag(1 2) collapse equ(level)) iv(lny2 lnL lndR) twostep robust small
eststo DAcol2

***** Dynamic Estimation, reverse causality; column (5)
xtreg lny L.lny lns lnndg L.DA if tagDA==1, re
xtreg lny L.lny lns lnndg L.DA if tagDA==1, fe
xtabond2 lny L.lny lns lnndg L.DA if tagDA==1, gmm(L.lny, lag(1 1) collapse) gmm(L.DA, lag(5 5) collapse equ(level)) iv(lns lnndg) twostep robust small
eststo DArev

		
*COMTRADE DATA
use data\dataset_balanced, clear

sort country t
bys country: gen n=(pop-pop[_n-1])/(pop[_n-1])
gen ndg=n+0.05

keep if comtrade==1
drop if moil>=.5|mpop<1
keep ISO country t *comtrade pop gdppc gdp_wdi R distR dist_cepii open cap ndg
keep ISO country t N* pop gdppc gdp_wdi R distR dist_cepii open cap ndg
compress

drop if t<2000

* share of goods exported
replace N_tot=N_tot/4252
replace N_50k=N_50k/4252
replace N_10p=N_10p/4252
gen limit=N_tot


* balanced panel
drop if gdppc==.
drop if cap==.
bys country: gen obs=_N
sum obs
drop if obs<r(max)
drop obs
egen id=group(country)
xtset id t



* relative terms
gen s=cap/gdp_wdi
local vars "s ndg gdppc pop distR N_tot N_50k N_10p"
foreach v of local vars{
bys t: egen m`v'=mean(`v')
replace `v'=`v'/m`v'
drop m`v'
}

* log RHS variables
gen lnndg=ln(ndg)
gen lns=ln(s)
gen lny=ln(gdppc)
gen lny2=lny^2
gen lnL=ln(pop)
gen lnR=ln(R)
gen lndR=ln(distR)
gen lnd=ln(dist_cepii)
gen DA=ln(N_tot)
gen DB=ln(N_50k)
gen DC=ln(N_10p)

la var ISO "Country ISO3 Code"
la var country "Country"
la var lny "(log) GDPpc"
la var lny2 "(log) GDPpc2"
la var lnL "(log) Population"
la var lns "(log) investment rate"
la var lnndg "(log) growth of population/depreciation/technology"
la var lndR "(log) Distance from Remote Destinations"
la var lnd "(log) Distance from Destinations"
la var DA "(log) Count: Total"
la var DB "(log) Count: Threshold $50,000"
la var DC "(log) Count: Threshold p[10]"

drop N* pop_wdi gdppc_wdi dist_cepii distR_cepii R_cepii gdp_wdi cap ndg open
xtset id t

gen dDA=d.DA
bys country: egen mdDA=mean(dDA)
xtset id t
sum mdDA, d
gen tagDA=1 if mdDA>r(p75)
tab country if tagDA==1, sum(limit)

gen dDB=d.DB
bys country: egen mdDB=mean(dDB)
xtset id t
sum mdDB, d
gen tagDB=1 if mdDB>r(p75)
tab country if tagDB==1, sum(limit)

gen dDC=d.DC
bys country: egen mdDC=mean(dDC)
xtset id t
sum mdDC, d
gen tagDC=1 if mdDC>r(p75)
tab country if tagDC==1, sum(limit)

****** Absolute Threshold: 50,000 USD
***** Dynamic Estimation, incl. lagged diversification; columns (3) and (4)
xtreg DB L.DB lny lnL lndR if tagDB==1, re
xtreg DB L.DB lny lnL lndR if tagDB==1, fe
xtabond2 DB L.DB lny lnL lndR if tagDB==1, gmm(L.DB, lag(1 1) collapse) gmm(L.lny, lag(3 3) collapse equ(level)) iv(lnL lndR) twostep robust small
eststo DBcol1

xtreg DB L.DB lny lny2 lnL lndR if tagDB==1, re
xtreg DB L.DB lny lny2 lnL lndR if tagDB==1, fe
xtabond2 DB L.DB lny lny2 lnL lndR if tagDB==1, gmm(L.DB, lag(1 1) collapse) gmm(L.lny, lag(3 3) collapse equ(level)) iv(lny2 lnL lndR) twostep robust small
eststo DBcol2

***** Dynamic Estimation, reverse causality; column (5)
xtreg lny L.lny lns lnndg L.DB if tagDB==1, re
xtreg lny L.lny lns lnndg L.DB if tagDB==1, fe
xtabond2 lny L.lny lns lnndg L.DB if tagDB==1, gmm(L.lny, lag(1 3) collapse) gmm(L.DB, lag(5 5) collapse equ(level)) iv(lns lnndg) twostep robust small
eststo DBrev



****** Relative Threshold: 10th percentile
***** Dynamic Estimation, incl. lagged diversification; columns (3) and (4)
xtreg DC L.DC lny lnL lndR if tagDC==1, re
xtreg DC L.DC lny lnL lndR if tagDC==1, fe
xtabond2 DC L.DC lny lnL lndR if tagDC==1, gmm(L.DC, lag(1 3) collapse) gmm(L.lny, lag(3 3) collapse equ(level)) iv(lnL lndR) twostep robust small
eststo DCcol1

xtreg DC L.DC lny lny2 lnL lndR if tagDC==1, re
xtreg DC L.DC lny lny2 lnL lndR if tagDC==1, fe
xtabond2 DC L.DC lny lny2 lnL lndR if tagDC==1, gmm(L.DC, lag(1 3) collapse) gmm(L.lny, lag(0 0) collapse equ(level)) iv(lny2 lnL lndR) twostep robust small
eststo DCcol2

***** Dynamic Estimation, reverse causality; column (5)
xtreg lny L.lny lns lnndg L.DC if tagDA==1, re
xtreg lny L.lny lns lnndg L.DC if tagDA==1, fe
xtabond2 lny L.lny lns lnndg L.DC if tagDA==1, gmm(L.lny, lag(2 6) collapse) gmm(L.DC, lag(9 .) collapse equ(level)) iv(lns lnndg) twostep robust small
eststo DCrev

		
**** TABLE 4: Exports to Rest of the World: Alternative Measures and Causality, BACI 1998-2009
esttab 	DAcol* DBcol* DCcol*, drop(_cons) sfmt(%5.3fc) se(%5.3f) star(a 0.1 * 0.05 ** 0.01) stats(r2 N N_g j ar2p hansenp)  mtitle label ///
		title(Exports to Rest of the World: Alternative Measures and Causality, BACI 1998-2009)
		
esttab 	DArev DBrev DCrev, drop(_cons) sfmt(%5.3fc) se(%5.3f) star(a 0.1 * 0.05 ** 0.01) stats(r2 N N_g j ar2p hansenp)  mtitle label ///
		title(Exports to Rest of the World: Alternative Measures and Causality, BACI 1998-2009) 


		
