* Reproduction of Table 4 Panel C of the paper
* "Export Diversification and Income Differences Reconsidered: The Extensive Product Margin in Theory and Application,"
* Review of World Economics, 152(2): 351-381; 2016, Karsten Mau

clear all
cd "C:\Users\Karsten Mau\Documents\Papiere\Export Diversification\"

*US DATA
use data\dataset_balanced, clear
keep if schott==1
drop if moil>=.5|mpop<1
keep ISO country t *schott pop gdppc R distUS
keep ISO country t N* pop gdppc R distUS
compress

drop if gdppc==.
* balanced panel
bys country: gen obs=_N
sum obs
drop if obs<r(max)
drop obs 
egen id=group(country)
xtset id t

* share of goods exported
replace N_tot=N_tot/N_pos
replace N_10k=N_10k/N_pos
replace N_10p=N_10p/N_pos
drop N_pos 

* relative terms
local vars "gdppc pop distUS N_tot N_10k N_10p"
foreach v of local vars{
bys t: egen m`v'=mean(`v')
replace `v'=`v'/m`v'
drop m`v'
}

* log RHS variables
gen lny=ln(gdppc)
gen lny2=lny^2
gen lnL=ln(pop)
gen lnR=ln(R)
gen lnd=ln(distUS)
gen DA=ln(N_tot)
gen DB=ln(N_10k)
gen DC=ln(N_10p)

la var ISO "Country ISO3 Code"
la var country "Country"
la var lny "(log) GDPpc"
la var lny2 "(log) GDPpc2"
la var lnL "(log) Population"
la var lnR "(log) Remoteness"
la var lnd "(log) Distance from US"
la var DA "(log) Count: Total"
la var DB "(log) Count: Threshold $10,000"
la var DC "(log) Count: Threshold p[10]"

drop N_tot_schott N_10k_schott N_10p_schott pop_wdi gdppc_wdi distUS R_cepii
xtset

****** Count: Total Number of Goods
***** Dynamic Estimation, incl. lagged diversification; columns (3) and (4)
xtreg DA L.DA lny lnL lnd, re
xtreg DA L.DA lny lnL lnd, fe
xtabond2 DA L.DA lny lnL lnd, gmm(L.DA, lag(2 4) collapse) gmm(L.lny, lag(3 3) collapse equ(level)) iv(lnL lnd) twostep robust small
eststo DAcol1

xtreg DA L.DA lny lny2 lnL lnd, re
xtreg DA L.DA lny lny2 lnL lnd, fe
xtabond2 DA L.DA lny lny2 lnL lnd, gmm(L.DA, lag(2 3) collapse) gmm(L.lny, lag(2 3) collapse equ(level)) iv(lny2 lnL lnd) twostep robust small
eststo DAcol2

		
****** Absolute Threshold: 50,000 USD
***** Dynamic Estimation, incl. lagged diversification; columns (3) and (4)
xtreg DB L.DB lny lnL lnd, re
xtreg DB L.DB lny lnL lnd, fe
xtabond2 DB L.DB lny lnL lnd, gmm(L.DB, lag(4 4) collapse) gmm(L.lny, lag(6 6) collapse equ(level)) iv(lnL lnd) twostep robust small
eststo DBcol1

xtreg DB L.DB lny lny2 lnL lnd, re
xtreg DB L.DB lny lny2 lnL lnd, fe
xtabond2 DB L.DB lny lny2 lnL lnd, gmm(L.DB, lag(4 4) collapse) gmm(L.lny, lag(4 6) collapse equ(level)) iv(lny2 lnL lnd) twostep robust small
eststo DBcol2


****** Relative Threshold: 10th percentile
***** Dynamic Estimation, incl. lagged diversification; columns (3) and (4)
xtreg DC L.DC lny lnL lnd, re
xtreg DC L.DC lny lnL lnd, fe
xtabond2 DC L.DC lny lnL lnd, gmm(L.DC, lag(2 3) collapse) gmm(L.lny, lag(4 4) collapse equ(level)) iv(lnL lnd) twostep robust small
eststo DCcol1

xtreg DC L.DC lny lny2 lnL lnd, re
xtreg DC L.DC lny lny2 lnL lnd, fe
xtabond2 DC L.DC lny lny2 lnL lnd, gmm(L.DC, lag(2 3) collapse) gmm(L.lny, lag(3 3) collapse equ(level)) iv(lny2 lnL lnd) twostep robust small
eststo DCcol2


**** TABLE 4: Exports to Rest the US: Alternative Measures and Causality, US Imports 1992-2009
esttab 	DAcol* DBcol* DCcol*, drop(_cons) sfmt(%5.3fc) se(%5.3f) star(a 0.1 * 0.05 ** 0.01) stats(r2 N_g j ar2p hansenp)  mtitle label ///
		title(Exports to Rest the US: Alternative Measures and Causality, US Imports 1992-2009) 

