* Reproduction of Table 6 and Figure 6 of the paper
* "Export Diversification and Income Differences Reconsidered: The Extensive Product Margin in Theory and Application,"
* Review of World Economics, 152(2): 351-381; 2016, Karsten Mau
**** COMTRADE DATA 1988-2013, unbalanced panel



clear all
cd "C:\Users\Karsten Mau\Documents\Papiere\Export Diversification\"
use data\dataset_balanced, clear

egen id=group(country)
xtset id t
*calculate growth rate and investment
gen dlny=d.gdppc/l.gdppc
gen I=cap/gdp_wdi
gen dI=d.I/l.I

* calculate lagged openness
gen lop5=1 if l6.open==0&l5.open==1
replace lop5=1 if l.lop5==1
replace lop5=0 if lop5==.
gen lop10=1 if l11.open==0&l10.open==1
replace lop10=1 if l.lop10==1
replace lop10=0 if lop10==.
gen lop0=open
replace lop0=0 if lop5==1
replace lop0=0 if lop10==1
replace lop5=0 if lop10==1
drop if open==.

codebook country if open==1 &l.open==0 & t>=1990
tab country if open==1 &l.open==0 & t>=1990, sum(t)


********************************
* Figure of Transition countries in the 1990s
preserve
gen lib=t if open==1&l.open==0
bys country: replace lib=0 if lib==.
gen lib2=t
sort country lib
bys country: replace lib2=lib2-lib2[_N]
bys country: replace lib=lib[_N]
sort country t
keep if lib>=1990
tab country
sort id t
collapse dlny, by(lib2)
drop if lib2<-10

sum dlny if lib2<=0
gen mpre=r(mean)
sum dlny if lib2>0
gen mpst=r(mean)
local pre=mpre
local pst=mpst

* 3-year growth rates
drop if dlny==.
gen mdlny=.
forvalues x=-10/25 {
replace mdlny=(dlny+dlny[_n-1]+dlny[_n+1])/3 if lib2==`x'
}

twoway 	scatter dlny lib2, xline(0) || line mpre lib2 if lib2<=0, lpattern(dash) || line mpst lib2 if lib2>0, lpattern(dash) || line mdlny lib2 ///
		, legend(off) graphregion(color(white)) ylab(,angle(h)) xtitle(" " "Years from Liberalization") xlab(-10(10)20) ///
		text(0.035 -7 "Years before" "Liberalization") text(0.005 17 "Years after Liberalization")
*graph export short_version\figure5.eps, replace
restore
********************************
********************************
* Figure of Transition countries in the 1990s
preserve
gen DA=N_tot_comtrade/4252
gen DB=N_50k_comtrade/4252
gen DC=N_10p_comtrade/4252
gen lib=t if open==1&l.open==0
bys country: replace lib=0 if lib==.
gen lib2=t
sort country lib
bys country: replace lib2=lib2-lib2[_N]
bys country: replace lib=lib[_N]
sort country t
keep if lib>=1990
codebook country
sort id t
collapse DA, by(lib2)
drop if lib2<-10
drop if lib2>15

sum DA if lib2<=0
gen mpre=r(mean)
sum DA if lib2>0
gen mpst=r(mean)
local pre=mpre
local pst=mpst

* 3-year growth rates
drop if DA==.
gen mDA=.
forvalues x=-10/25 {
replace mDA=(DA+DA[_n-1]+DA[_n+1])/3 if lib2==`x'
}

twoway 	scatter DA lib2, xline(0) || line mpre lib2 if lib2<=0, lpattern(dash) || line mpst lib2 if lib2>0, lpattern(dash) || line mDA lib2 ///
		, legend(off) graphregion(color(white)) ylab(,angle(h)) xtitle(" " "Years from Liberalization") xlab(-5(5)15) ///
		text(0.45 -4 "Years before" "Liberalization") text(0.25 8 "Years after Liberalization") name(DA, replace)
*graph export short_version\figure6a.eps, replace
restore
********************************
********************************
* Figure of Transition countries in the 1990s
preserve
gen DA=N_tot_comtrade/4252
gen DB=N_50k_comtrade/4252
gen DC=N_10p_comtrade/4252
gen lib=t if open==1&l.open==0
bys country: replace lib=0 if lib==.
gen lib2=t
sort country lib
bys country: replace lib2=lib2-lib2[_N]
bys country: replace lib=lib[_N]
sort country t
keep if lib>=1990
codebook country
sort id t
collapse DB, by(lib2)
drop if lib2<-10
drop if lib2>15

sum DB if lib2<=0
gen mpre=r(mean)
sum DB if lib2>0
gen mpst=r(mean)
local pre=mpre
local pst=mpst

* 3-year growth rates
drop if DB==.
gen mDB=.
forvalues x=-10/25 {
replace mDB=(DB+DB[_n-1]+DB[_n+1])/3 if lib2==`x'
}

twoway 	scatter DB lib2, xline(0) || line mpre lib2 if lib2<=0, lpattern(dash) || line mpst lib2 if lib2>0, lpattern(dash) || line mDB lib2 ///
		, legend(off) graphregion(color(white)) ylab(,angle(h)) xtitle(" " "Years from Liberalization") xlab(-5(5)15) ///
		text(0.175 -4 "Years before" "Liberalization") text(0.075 8 "Years after Liberalization") name(DB, replace)
*graph export short_version\figure6b.eps, replace
restore
********************************
********************************
* Figure of Transition countries in the 1990s
preserve
gen DA=N_tot_comtrade/4252
gen DB=N_50k_comtrade/4252
gen DC=N_10p_comtrade/4252
gen lib=t if open==1&l.open==0
bys country: replace lib=0 if lib==.
gen lib2=t
sort country lib
bys country: replace lib2=lib2-lib2[_N]
bys country: replace lib=lib[_N]
sort country t
keep if lib>=1990
codebook country
sort id t
collapse DC, by(lib2)
drop if lib2<-10
drop if lib2>15

sum DC if lib2<=0
gen mpre=r(mean)
sum DC if lib2>0
gen mpst=r(mean)
local pre=mpre
local pst=mpst

* 3-year growth rates
drop if DC==.
gen mDC=.
forvalues x=-10/25 {
replace mDC=(DC+DC[_n-1]+DC[_n+1])/3 if lib2==`x'
}

twoway 	scatter DC lib2, xline(0) || line mpre lib2 if lib2<=0, lpattern(dash) || line mpst lib2 if lib2>0, lpattern(dash) || line mDC lib2 ///
		, legend(off) graphregion(color(white)) ylab(,angle(h)) xtitle(" " "Years from Liberalization") xlab(-5(5)15) ///
		text(0.035 -4 "Years before" "Liberalization") text(0.025 8 "Years after Liberalization") name(DC, replace)
*graph export short_version\figure6c.eps, replace
restore
********************************

keep if comtrade==1
drop if moil>=.5|mpop<1
keep ISO country t *comtrade pop gdppc distR open lop* I dI dlny
keep ISO country t N* pop gdppc distR open lop* I dI dlny
compress

* unbalanced panel
bys country: gen obs=_N
sum obs
drop obs
egen id=group(country)
xtset id t

* share of goods exported
gen N_pos=4252
replace N_tot=N_tot/N_pos
replace N_50k=N_50k/N_pos
replace N_10p=N_10p/N_pos

* log RHS variables
gen lny=ln(gdppc)
gen lny2=lny^2
gen lnL=ln(pop)
gen lndR=ln(distR)
gen DA=N_tot
gen DB=N_50k
gen DC=N_10p

drop N* pop_wdi gdppc_wdi distR_cepii 



* Include EU accessors of 2004 not coded due to missing data before 1990s
* Estonia coded open in sachs-warner but closed in wacziarg-welch, here open since 1992
replace lop0=1 if country=="Czech Republic"
replace lop0=1 if country=="Slovak Republic"
replace lop0=1 if country=="Slovenia"
replace lop0=1 if country=="Estonia"

replace lop5=1 if country=="Czech Republic"&t>1996
replace lop5=1 if country=="Slovak Republic"&t>1996
replace lop5=1 if country=="Slovenia"&t>1996
replace lop5=1 if country=="Estonia"&t>1997
replace lop5=0 if lop5==.

replace lop10=1 if country=="Czech Republic"&t>2001
replace lop10=1 if country=="Slovak Republic"&t>2001
replace lop10=1 if country=="Slovenia"&t>2001
replace lop10=1 if country=="Estonia"&t>2002
replace lop10=0 if lop5==.

replace lop0=0 if lop5==1
replace lop0=0 if lop10==1
replace lop5=0 if lop10==1



gen eu=0
replace eu=1 if country=="Bulgaria"
replace eu=1 if country=="Hungary"
replace eu=1 if country=="Latvia"
replace eu=1 if country=="Lithuania"
replace eu=1 if country=="Poland"
replace eu=1 if country=="Romania"
replace eu=1 if country=="Turkey"
replace eu=1 if country=="Czech Republic"
replace eu=1 if country=="Slovak Republic"
replace eu=1 if country=="Slovenia"
replace eu=1 if country=="Estonia"

xtset
bys id: gen tag=1 if lop10==1&l.lop10==0
bys id: replace tag=1 if lop5==1&l.lop5==0
bys id: replace tag=1 if lop0==1&l.lop0==0
sort id tag
bys id: replace tag=tag[1]
xtset
codebook country if tag==1
tab country if tag==1&eu==1


* Estimation
fvset base 2000 t
xtreg dlny lop0 lop5 lop10 i.t, fe robust
eststo dlnyall
xtreg dlny lop0 lop5 lop10 i.t if eu==0, fe robust
eststo dlnynoneu
xtreg dlny lop0 lop5 lop10 i.t if eu==1|tag==., fe robust
eststo dlnyeu

xtreg I lop0 lop5 lop10  i.t, fe robust
eststo Iall
xtreg I lop0 lop5 lop10 i.t if eu==0, fe robust
eststo Inoneu
xtreg I lop0 lop5 lop10 i.t if eu==1|tag==., fe robust
eststo Ieu

xtreg DA lny lnL lndR lop0 lop5 lop10  i.t, fe robust
eststo DAall
xtreg DA lny lnL lndR lop0 lop5 lop10 i.t if eu==0, fe robust
eststo DAnoneu
xtreg DA lny lnL lndR lop0 lop5 lop10 i.t if eu==1|tag==., fe robust 
eststo DAeu

xtreg DB lny lnL lndR lop0 lop5 lop10  i.t, fe robust
eststo DBall
xtreg DB lny lnL lndR lop0 lop5 lop10 i.t if eu==0, fe robust
eststo DBnoneu
xtreg DB lny lnL lndR lop0 lop5 lop10 i.t if eu==1|tag==., fe robust
eststo DBeu

xtreg DC lny lnL lndR lop0 lop5 lop10  i.t, fe robust
eststo DCall
xtreg DC lny lnL lndR lop0 lop5 lop10 i.t if eu==0, fe robust
eststo DCnoneu
xtreg DC lny lnL lndR lop0 lop5 lop10 i.t if eu==1|tag==., fe robust
eststo DCeu

esttab 	*all, drop(lny lnL lndR _cons *.*) sfmt(%5.3fc) se(%5.3f) star(a 0.1 * 0.05 ** 0.01) stats(r2 N N_g)  mtitle label 
esttab 	*noneu, drop(lny lnL lndR _cons *.*) sfmt(%5.3fc) se(%5.3f) star(a 0.1 * 0.05 ** 0.01) stats(r2 N N_g)  mtitle label
esttab dlnyeu Ieu DAeu DBeu DCeu, drop(lny lnL lndR _cons *.*) sfmt(%5.3fc) se(%5.3f) star(a 0.1 * 0.05 ** 0.01) stats(r2 N N_g)  mtitle label 






